==> tdm_2.0.0.tar.gz: tdm/R/all.Amidihinfusionsm.R <==
all.Amidihinfusionsm<-function(){
     cat("\n")                                                                       
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Thesm_conc_input()
     cat("-----------------------------------------------------------------------\n")                                                              
     cat("\n")
     note_for_close_window()
     AmidihinfusionSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)"),value=c(0))
     AmidihinfusionSMMpar<-edit(AmidihinfusionSMMpar)
     AmidihinfusionSMMpar<-ycheck(AmidihinfusionSMMpar)
     cat("\n")
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_input()
     cat("------------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihinfusionSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                            
     AmidihinfusionSMpar<-edit(AmidihinfusionSMpar)                                            
     AmidihinfusionSMpar<-mscheck(AmidihinfusionSMpar)                                         
     cat("\n")
     Amidihinfusion.sm(length(AmidihinfusionSMpar$ts),AmidihinfusionSMpar$conc,AmidihinfusionSMpar$ts,AmidihinfusionSMMpar[3,2],AmidihinfusionSMMpar[2,2],AmidihinfusionSMMpar[5,2],AmidihinfusionSMMpar[1,2],AmidihinfusionSMMpar[4,2],AmidihinfusionSMMpar[6,2],AmidihinfusionSMMpar[8,2],AmidihinfusionSMMpar[7,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_output()
     cat("------------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-0.8*AmidihinfusionSMMpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)     
     cat("\n")   
     Amidihinfusion.more()                   
}

==> tdm_2.2.2.tar.gz: tdm/R/all.Amidihinfusionsm.R <==
all.Amidihinfusionsm<-function(){
     cat("\n")                                                                       
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--     \n")
     note_for_Thesm_conc_input()
     cat("-----------------------------------------------------------------------\n")                                                              
     cat("\n")
     note_for_close_window()
     AmidihinfusionSMMpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)"),value=c(0))
     AmidihinfusionSMMpar<-edit(AmidihinfusionSMMpar)
##     AmidihinfusionSMMpar<-ycheck(AmidihinfusionSMMpar)
     cat("\n")
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_input()
     cat("------------------------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     AmidihinfusionSMpar<-data.frame(ts=c(0),conc=c(0))                                                                                                                            
     AmidihinfusionSMpar<-edit(AmidihinfusionSMpar)                                            
     AmidihinfusionSMpar<-mscheck(AmidihinfusionSMpar)                                         
     cat("\n")
     Amidihinfusion.sm(length(AmidihinfusionSMpar$ts),AmidihinfusionSMpar$conc,AmidihinfusionSMpar$ts,AmidihinfusionSMMpar[3,2],AmidihinfusionSMMpar[2,2],AmidihinfusionSMMpar[5,2],AmidihinfusionSMMpar[1,2],AmidihinfusionSMMpar[4,2],AmidihinfusionSMMpar[6,2],AmidihinfusionSMMpar[8,2],AmidihinfusionSMMpar[7,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("------------------------------------------------------------------------\n")
     cat("    --Aminophylline dihydrous iv infusion input data information--      \n")
     note_for_Theinfusionsm_output()
     cat("------------------------------------------------------------------------\n")
     show(samplesStats("*"))
     cat("\n")
     C<-0.8*AmidihinfusionSMMpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)     
     cat("\n")   
     Amidihinfusion.more()                   
}
